@@ -7,7 +7,7 @@ from __future__ import print_function
     This uses the Python type P4API.P4Adapter, which is a wrapper for the
     Perforce ClientApi object.
     
-    $Id: //depot/r18.2/p4-python/P4.py#1 $
+    $Id: //depot/r22.1/p4-python/P4.py#2 $
     
     #*******************************************************************************
     # Copyright (c) 2007-2010, Perforce Software, Inc.  All rights reserved.
@@ -370,17 +370,20 @@ def processFilelog(h):
             if (not "how" in h) or (n >= len(h["how"]) or h["how"][n] == None):
                 continue
             else:
+                number_sign = '#'
+                if type(h["depotFile"]) == bytes:
+                    number_sign = b'#'
                 for m, how in enumerate( h[ "how" ][ n ] ):
                     file = h[ "file" ][ n ][ m ]
-                    srev = h[ "srev" ][ n ][ m ].lstrip('#')
-                    erev = h[ "erev" ][ n ][ m ].lstrip('#')
+                    srev = h[ "srev" ][ n ][ m ].lstrip(number_sign)
+                    erev = h[ "erev" ][ n ][ m ].lstrip(number_sign)
                     
-                    if srev == "none":
+                    if srev == "none" or srev == b"none":
                         srev = 0
                     else:
                         srev = int( srev )
                 
-                    if erev == "none":
+                    if erev == "none" or erev == b"none":
                         erev = 0
                     else:
                         erev = int( erev )
@@ -590,17 +593,20 @@ class P4(P4API.P4Adapter):
             setattr(self, k, v)
                 
         flatArgs = self.__flatten(args)
+
+        if self.logger:
+            self.logger.info("p4 " + " ".join(flatArgs))
         
         # if encoding is set, translate to Bytes
         if hasattr(self,"encoding") and self.encoding and not self.encoding == 'raw':
             result = []
             for s in flatArgs:
-                result.append( s.encode(self.encoding) )
+                if isinstance(s, str):
+                    result.append( s.encode(self.encoding) )
+                else:
+                    result.append(s)
             flatArgs = result
         
-        if self.logger:
-            self.logger.info("p4 " + " ".join(flatArgs))
-        
         try:
             result = P4API.P4Adapter.run(self, *flatArgs)
         except P4Exception as e:
@@ -884,6 +890,8 @@ class P4(P4API.P4Adapter):
             self.client = oldName
             
         finally:
+            ws._options = ws._options.replace(' locked ',' unlocked ')    
+            self.save_client(ws)    
             self.delete_client(name)
             shutil.rmtree(root)
 
