@@ -27,7 +27,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $Id: //depot/r18.2/p4-python/P4API.cpp#1 $
+ * $Id: //depot/r22.1/p4-python/P4API.cpp#1 $
  *
  * Build instructions:
  *  Use Distutils - see accompanying setup.py
@@ -237,7 +237,7 @@ static PyObject * P4Adapter_run(P4Adapter * self, PyObject * args)
     // the other hack is that the API expects (char * const *), but this cannot be stored
     // a std::vector<>, because it cannot exchange pointers
     
-    return self->clientAPI->Run(GetPythonString(cmd), argv.size(), 
+    return self->clientAPI->Run(GetPythonString(cmd), (int)argv.size(), 
         (argv.size() > 0) ? (char * const *) &argv[0] : NULL );
 }
 
@@ -322,7 +322,7 @@ static PyObject * P4API_dvcs_init(P4Adapter * self, PyObject * args, PyObject *
     PyObject * unicode = NULL;
 
     PythonDebug debug;
-    SpecMgr specMgr(&debug);
+    p4py::SpecMgr specMgr(&debug);
     PythonClientUser ui(&debug, &specMgr);
     Error e;
 
@@ -363,7 +363,7 @@ static PyObject * P4API_dvcs_init(P4Adapter * self, PyObject * args, PyObject *
     personalServer->InitLocalServer(&ui, &e);
     if( found_error(e) ) return NULL;
 
-    P4Result& results = ui.GetResults();
+    p4py::P4Result& results = ui.GetResults();
     return results.GetOutput();
 }
 
@@ -381,7 +381,7 @@ static PyObject * P4API_dvcs_clone(P4Adapter * self, PyObject * args, PyObject *
     PyObject * progress = NULL;
 
     PythonDebug debug;
-    SpecMgr specMgr(&debug);
+    p4py::SpecMgr specMgr(&debug);
     PythonClientUser ui(&debug, &specMgr);
     Error e;
 
@@ -451,7 +451,7 @@ static PyObject * P4API_dvcs_clone(P4Adapter * self, PyObject * args, PyObject *
     personalServer->CloneFromRemote( depth, noArchives, (char *) 0, &ui, &e );
     if( found_error(e) ) return NULL;
 
-    P4Result& results = ui.GetResults();
+    p4py::P4Result& results = ui.GetResults();
     return results.GetOutput();
 }
 
@@ -983,7 +983,7 @@ static PyObject *
 {
     P4Map *self = (P4Map *) type->tp_alloc(type, 0);
     if (self != NULL) { 
-        self->map = new P4MapMaker();
+        self->map = new p4py::P4MapMaker();
     }
     
     return (PyObject *) self;
@@ -1094,7 +1094,7 @@ static PyObject *
     if (!rmap)
        return (PyObject *) rmap;
 
-    rmap->map = new P4MapMaker( *self->map );
+    rmap->map = new p4py::P4MapMaker( *self->map );
     rmap->map->Reverse();
     
     return (PyObject *) rmap;
@@ -1147,7 +1147,7 @@ static PyObject *
 
     result = (P4Map *) PyObject_CallObject(mapClass, NULL);
     delete result->map;
-    result->map = P4MapMaker::Join(left->map, right->map);
+    result->map = p4py::P4MapMaker::Join(left->map, right->map);
     return (PyObject *) result;
 }
 
