@@ -25,13 +25,16 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $Id: //depot/r18.2/p4-python/P4Result.h#1 $
+ * $Id: //depot/r22.1/p4-python/P4Result.h#1 $
  *
  */
 
 #ifndef P4RESULT_H
 #define P4RESULT_H
 
+namespace p4py
+{
+
 class P4Result
 {
 public:
@@ -84,5 +87,6 @@ private:
     int           apiLevel;
     bool	  fatal;
 };
+}
 
 #endif
