@@ -25,7 +25,7 @@ ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-$Id: //depot/r18.2/p4-python/PythonClientAPI.cpp#1 $
+$Id: //depot/r22.1/p4-python/PythonClientAPI.cpp#1 $
 *******************************************************************************/
  
 #include <Python.h>
@@ -619,7 +619,7 @@ PyObject * PythonClientAPI::Convert(const char * charset, PyObject * content)
 	const char * contentAsUTF8 = PyBytes_AS_STRING(bytes);
 
 	int retlen = 0;
-	const char * converted = cvt->FastCvt(contentAsUTF8, strlen(contentAsUTF8), &retlen);
+	const char * converted = cvt->FastCvt(contentAsUTF8, (int)strlen(contentAsUTF8), &retlen);
 	Py_DECREF( bytes ); // we do not need this object anymore
 
 	if (converted == NULL) {
@@ -811,7 +811,7 @@ PyObject * PythonClientAPI::Run( const char *cmd, int argc, char * const *argv )
 	    return NULL;
     }
 
-    P4Result &results = ui.GetResults();
+    p4py::P4Result &results = ui.GetResults();
 
     if ( results.ErrorCount() && exceptionLevel ) {
 	Except( "P4#run", "Errors during command execution", cmdString.Text() );
@@ -1182,6 +1182,7 @@ void PythonClientAPI::Except( const char *func, const char *msg )
 	PyList_SET_ITEM(list, 2, ui.GetResults().GetWarnings());
 
 	PyErr_SetObject(P4Error, list);
+    Py_DECREF(list);
     }
 }
 
