@@ -26,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $Id: //depot/r18.2/p4-python/PythonClientAPI.h#1 $
+ * $Id: //depot/r22.1/p4-python/PythonClientAPI.h#1 $
  *
  * Build instructions:
  *  Use Distutils - see accompanying setup.py
@@ -311,7 +311,7 @@ private:
     PythonClientUser	ui;
     Enviro *		enviro;
     PythonDebug		debug;
-    SpecMgr		specMgr;
+    p4py::SpecMgr		specMgr;
     StrBufDict		specDict;
     StrBuf		prog;
     StrBuf		version;
