@@ -25,7 +25,7 @@ ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-$Id: //depot/r18.2/p4-python/PythonClientUser.cpp#1 $
+$Id: //depot/r22.1/p4-python/PythonClientUser.cpp#1 $
 
 *******************************************************************************/
  
@@ -63,7 +63,7 @@ $Id: //depot/r18.2/p4-python/PythonClientUser.cpp#1 $
 
 using namespace std;
 
-PythonClientUser::PythonClientUser( PythonDebug * dbg, SpecMgr *s )
+PythonClientUser::PythonClientUser( PythonDebug * dbg, p4py::SpecMgr *s )
     : specMgr(s),
       debug(dbg),
       results(dbg, s)
