@@ -26,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $Id: //depot/r18.2/p4-python/PythonClientUser.h#1 $
+ * $Id: //depot/r22.1/p4-python/PythonClientUser.h#1 $
  *
  * Build instructions:
  *  Use Distutils - see accompanying setup.py
@@ -43,7 +43,7 @@ class ClientProgress;
 class PythonClientUser: public ClientUser, public KeepAlive
 {
 public:
-    PythonClientUser(PythonDebug *dbg, SpecMgr *s);
+    PythonClientUser(PythonDebug *dbg, p4py::SpecMgr *s);
 
     virtual ~PythonClientUser();
 
@@ -106,7 +106,7 @@ public:
         track = t;
     }
 
-    P4Result& GetResults()
+    p4py::P4Result& GetResults()
     {
         return results;
     }
@@ -128,9 +128,9 @@ private:
 
 private:
     StrBuf              cmd;
-    SpecMgr *           specMgr;
+    p4py::SpecMgr *     specMgr;
     PythonDebug *       debug;
-    P4Result            results;
+    p4py::P4Result      results;
     PyObject *          input;
     PyObject *          resolver;
     PyObject *          handler;
