@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: //depot/r18.2/p4-python/PythonMessage.cpp#1 $
+ * $Id: //depot/r22.1/p4-python/PythonMessage.cpp#1 $
  *
  */
 
@@ -49,7 +49,7 @@
 #include "SpecMgr.h"
 #include "PythonMessage.h"
 
-PythonMessage::PythonMessage(const Error *e, SpecMgr * s)
+PythonMessage::PythonMessage(const Error *e, p4py::SpecMgr * s)
     :	specMgr(s)
 {
 	// The following is a hack. 
