@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: //depot/r18.2/p4-python/PythonMessage.h#1 $
+ * $Id: //depot/r22.1/p4-python/PythonMessage.h#1 $
  *
  */
 
@@ -45,10 +45,10 @@ class PythonMessage
 {
 private:
     Error err;
-    SpecMgr * specMgr;
+    p4py::SpecMgr * specMgr;
 
 public:
-    PythonMessage(const Error * other, SpecMgr * s);
+    PythonMessage(const Error * other, p4py::SpecMgr * s);
 
 public:
     PyObject * getText();
