@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $Id: //depot/r18.2/p4-python/PythonTypes.h#1 $
+ * $Id: //depot/r22.1/p4-python/PythonTypes.h#1 $
  *
  * Build instructions:
  *  Use Distutils - see accompanying setup.py
@@ -40,7 +40,10 @@
 class PythonClientAPI;
 class PythonMergeData;
 class PythonActionMergeData;
+
+namespace p4py {
 class P4MapMaker;
+}
 class PythonMessage;
 
 /* C container for P4Adapter */
@@ -64,7 +67,7 @@ typedef struct {
 /* C container for Map */
 typedef struct {
     PyObject_HEAD
-    P4MapMaker *map;
+    p4py::P4MapMaker *map;
 } P4Map;
 
 /* C container for Map */
