@@ -23,7 +23,7 @@
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
- $Id: //depot/r18.2/p4-python/SpecMgr.cpp#1 $
+ $Id: //depot/r22.1/p4-python/SpecMgr.cpp#1 $
  *******************************************************************************/
 
 /*******************************************************************************
@@ -54,7 +54,7 @@
 
 using namespace std;
 
-
+namespace p4py {
 
 struct specdata {
     const char *type;
@@ -86,6 +86,7 @@ struct specdata {
 	"Description;code:206;type:text;rq;seq:7;;"
 	"JobStatus;code:207;fmt:I;type:select;seq:9;;"
 	"Jobs;code:208;type:wlist;seq:8;len:32;;"
+	"Stream;code:214;type:line;len:64;;"
 	"Files;code:210;type:llist;len:64;;"
     },
     {
@@ -128,27 +129,10 @@ struct specdata {
 	"Map;code:257;rq;len:64;;"
 	"SpecMap;code:259;type:wlist;len:64;;"
     },
-    {
-	"extension",
-	"ExtName;code:901;type:line;opt:once;len:64;;"
-	"ExtDescription;code:902;type:text;opt:once;len:128;;"
-	"ExtVersion;code:903;type:line;opt:once;len:32;;"
-	"ExtUUID;code:904;type:line;opt:once;len:36;;"
-	"ExtRev;code:905;type:word;opt:once;len:20;;"
-	"ExtMaxScriptTime;code:913;type:word;len:12;;"
-	"ExtMaxScriptMem;code:914;type:word;len:12;;"
-	"ExtAllowedGroups;code:915;type:wlist;len:32;opt:default;;"
-	"ExtEnabled;code:916;type:word;opt:default;len:12;;"
-	"ExtP4USER;code:917;type:word;opt:default;len:12;;"
-	"Name;code:906;type:line;opt:default;len:32;;"
-	"Owner;code:907;type:word;opt:default;len:36;;"
-	"Update;code:908;type:date;opt:always;fmt:L;len:20;;"
-	"Description;code:909;type:text;opt:required;len:128;;"
-	"ExtConfig;code:912;type:text;opt:required;len:256;;"
-    },
     {
 	"group",
 	"Group;code:401;rq;ro;len:32;;"
+	"Description;code:NNN;type:text;fmt:L:len:128;;"
 	"MaxResults;code:402;type:word;len:12;;"
 	"MaxScanRows;code:403;type:word;len:12;;"
 	"MaxLockTime;code:407;type:word;len:12;;"
@@ -227,6 +211,7 @@ struct specdata {
 	"Users;code:459;len:8;;"
 	"Files;code:460;len:8;;"
 	"Repos;code:462;len:8;;"
+	"ExtraCapabilities;code:463;type:llist;len:512;;"
     },
     {
 	"protect",
@@ -252,15 +237,20 @@ struct specdata {
     },
     {
 	"repo",
-	"Repo;code:1001;rq;ro;len:128;;"
-	"Owner;code:1002;len:32;;"
+	"Repo;code:1001;rq;ro;fmt:L;len:128;;"
+	"Owner;code:1002;fmt:R;len:32;;"
 	"Created;code:1003;type:date;ro;fmt:L;len:20;;"
-	"Pushed;code:1004;type:date;ro;fmt:L;len:20;;"
-	"ForkedFrom;code:1005;ro;len:128;;"
+	"Pushed;code:1004;type:date;ro;fmt:R;len:20;;"
+	"ForkedFrom;code:1005;ro;fmt:L;len:128;;"
 	"Description;code:1006;type:text;len:128;;"
-	"DefaultBranch;code:1007;len:32;;"
-	"MirroredFrom;code:1008;len:32;;"
+	"DefaultBranch;code:1007;fmt:L;len:32;;"
+	"MirroredFrom;code:1008;fmt:R;len:32;;"
 	"Options;code:1009;type:select;len:10;val:lfs/nolfs;;"
+	"GconnMirrorServerId;code:1010;fmt:L;len:32;;"
+	"GconnMirrorSecretToken;code:NNN;len:36;;"
+	"GconnMirrorStatus;code:NNN;len:8;;"
+	"GconnMirrorExcludedBranches;code:NNN;len:256;;"
+	"GconnMirrorHideFetchUrl;code:NNN;len:5;;"
     },
     {
 	"server",
@@ -276,6 +266,7 @@ struct specdata {
 	"Description;code:757;type:text;len:128;;"
 	"User;code:761;type:line;len:64;;"
 	"AllowedAddresses;code:763;type:wlist;len:64;;"
+	"UpdateCachedRepos;code:766;type:wlist;len:64;;"
 	"ClientDataFilter;code:758;type:wlist;len:64;;"
 	"RevisionDataFilter;code:759;type:wlist;len:64;;"
 	"ArchiveDataFilter;code:760;type:wlist;len:64;;"
@@ -289,6 +280,7 @@ struct specdata {
 	"Values;code:354;type:wlist;words:2;;"
 	"Presets;code:355;type:wlist;words:2;;"
 	"Openable;code:362;type:wlist;words:2;;"
+	"Maxwords;code:361;type:wlist;words:2;;"
 	"Comments;code:356;type:text;;"
     },
     {
@@ -296,18 +288,21 @@ struct specdata {
 	"Stream;code:701;rq;ro;len:64;;"
 	"Update;code:705;type:date;ro;fmt:L;len:20;;"
 	"Access;code:706;type:date;ro;fmt:L;len:20;;"
-	"Owner;code:704;len:32;;"
-	"Name;code:703;rq;type:line;len:32;;"
+	"Owner;code:704;len:32;open:isolate;;"
+	"Name;code:703;rq;type:line;len:32;open:isolate;;"
 	"Parent;code:702;rq;len:64;open:isolate;;"
 	"Type;code:708;rq;len:32;open:isolate;;"
-	"Description;code:709;type:text;len:128;;"
+	"Description;code:709;type:text;len:128;open:isolate;;"
 	"Options;code:707;type:line;len:64;val:"
-	"allsubmit/ownersubmit,unlocked/locked,"
-	"toparent/notoparent,fromparent/nofromparent,"
-	"mergedown/mergeany;;"
-	"Paths;code:710;rq;type:wlist;words:2;maxwords:3;len:64;open:isolate;;"
-	"Remapped;code:711;type:wlist;words:2;len:64;open:isolate;;"
-	"Ignored;code:712;type:wlist;words:1;len:64;open:isolate;;"
+	    "allsubmit/ownersubmit,unlocked/locked,"
+	    "toparent/notoparent,fromparent/nofromparent,"
+	    "mergedown/mergeany;open:isolate;;"
+	"ParentView;code:NNN;rq;open:isolate;"
+	"pre:inherit;val:noinherit/inherit;;"
+	"Components;code:NNN;type:wlist;words:3;maxwords:4;len:64;open:propagate;fmt:C;;"
+	"Paths;code:710;rq;type:wlist;words:2;maxwords:3;len:64;open:propagate;fmt:C;;"
+	"Remapped;code:711;type:wlist;words:2;len:64;open:propagate;fmt:C;;"
+	"Ignored;code:712;type:wlist;words:1;len:64;open:propagate;fmt:C;;"
 	"View;code:713;type:wlist;words:2;len:64;;"
 	"ChangeView;code:714;type:llist;ro;len:64;;"
     },
@@ -336,6 +331,8 @@ struct specdata {
     { 0, 0}
 };
 
+
+
 SpecMgr::SpecMgr(PythonDebug * dbg)
     : debug(dbg)
 {
@@ -564,10 +561,10 @@ void SpecMgr::SplitKey( const StrPtr *key, StrBuf &base, StrBuf &index ) {
     base = *key;
     index = "";
     for( size_t i = key->Length(); i; i-- ) {
-	char prev = (*key)[i - 1];
+	char prev = (*key)[(p4size_t)i - 1];
 	if( !isdigit(prev) && prev != ',' ) {
-	    base.Set(key->Text(), i);
-	    index.Set(key->Text() + i);
+	    base.Set(key->Text(), (p4size_t)i);
+	    index.Set(key->Text() + (p4size_t)i);
 	    break;
 	}
     }
@@ -653,7 +650,7 @@ void SpecMgr::InsertItem( PyObject * dict, const StrPtr *var, const StrPtr *val
 
     for( const char *c = 0; (c = index.Contains(comma)); ) {
 	StrBuf level;
-	level.Set(index.Text(), c - index.Text());
+	level.Set(index.Text(), (int)(c - index.Text()));
 	index.Set(c + 1);
 
 	// Found another level so we need to get/create a nested array
@@ -697,7 +694,7 @@ void SpecMgr::InsertItem( PyObject * dict, const StrPtr *var, const StrPtr *val
     }
 
     buf = "... ";
-    buf << PyList_Size(list) << "] = " << val->Text();
+    buf << (int)PyList_Size(list) << "] = " << val->Text();
 
     debug->debug ( P4PYDBG_DATA, buf.Text() );
 
@@ -729,6 +726,8 @@ PyObject * SpecMgr::NewSpec( StrPtr *specDef ) {
     return newObj;
 }
 
+}
+
 #if PY_MAJOR_VERSION >= 3
 
 PyObject * CreatePythonStringAndSize(const char * text, size_t len, const char *encoding) {
