@@ -23,7 +23,7 @@ ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-$Id: //depot/r18.2/p4-python/SpecMgr.h#1 $
+$Id: //depot/r22.1/p4-python/SpecMgr.h#1 $
 *******************************************************************************/
 
 /*******************************************************************************
@@ -41,6 +41,8 @@ $Id: //depot/r18.2/p4-python/SpecMgr.h#1 $
 
 class StrBufDict;
 
+namespace p4py {
+
 class SpecMgr 
 {
 public:
@@ -108,5 +110,5 @@ private:
 	PythonDebug *	debug;
 	StrBufDict *	specs;
 };
-
+}
 #endif
